***********
Bug Reports
***********

If you have found a bug in Sherpa please report it. The preferred way
is to create a new issue on the Sherpa
`GitHub issue page <https://github.com/sherpa/sherpa/issues/>`_; that
requires creating a free account on GitHub if you do not have one.
For those using Sherpa as part of
`CIAO <https://cxc.harvard.edu/ciao/>`_, please use the
`CXC HelpDesk system <https://cxc.harvard.edu/help/>`_.

Please include an example that demonstrates the issue that will allow
the developers to reproduce and fix the problem. You may be asked to
also provide information about your operating system and a full Python
stack trace; the Sherpa developers will walk you through obtaining a
stack trace if it is necessary.

